@@ -8,7 +8,7 @@
 #include "updater_cert.h"
 
 #ifdef FZ_WINDOWS
-#include "registry.h"
+#include <libfilezilla/glue/registry.hpp>
 #endif
 
 #include "../include/engine_context.h"
@@ -16,7 +16,6 @@
 #include "../include/FileZillaEngine.h"
 #include "../include/misc.h"
 #include "../include/version.h"
-#include "../include/writer.h"
 
 #include <libfilezilla/file.hpp>
 #include <libfilezilla/hash.hpp>
@@ -29,9 +28,6 @@ namespace {
 struct run_event_type;
 typedef fz::simple_event<run_event_type, bool> run_event;
 
-option_registrator r(&register_updater_options);
-}
-
 unsigned int register_updater_options()
 {
 	static int const value = register_options({
@@ -47,6 +43,20 @@ unsigned int register_updater_options()
 	return value;
 }
 
+option_registrator r(&register_updater_options);
+}
+
+optionsIndex mapOption(updaterOptions opt)
+{
+	static unsigned int const offset = register_updater_options();
+
+	auto ret = optionsIndex::invalid;
+	if (opt < OPTIONS_UPDATER_NUM) {
+		return static_cast<optionsIndex>(opt + offset);
+	}
+	return ret;
+}
+
 static CUpdater* instance = 0;
 
 CUpdater::CUpdater(CFileZillaEngineContext& engine_context)
@@ -169,9 +179,9 @@ fz::uri CUpdater::GetUrl()
 
 	// Add information about package
 	// Installer always writes to 32bit section
-	auto key = regkey(HKEY_CURRENT_USER, L"Software\\FileZilla Client", true, regkey::regview_32);
+	auto key = fz::regkey(HKEY_CURRENT_USER, L"Software\\FileZilla Client", true, fz::regkey::regview_32);
 	if (!key) {
-		key.open(HKEY_LOCAL_MACHINE, L"Software\\FileZilla Client", true, regkey::regview_32);
+		key.open(HKEY_LOCAL_MACHINE, L"Software\\FileZilla Client", true, fz::regkey::regview_32);
 	}
 
 	if (key.has_value(L"Updated")) {
@@ -285,7 +295,7 @@ int CUpdater::Request(fz::uri const& uri)
 
 	CServer server(fz::equal_insensitive_ascii(uri.scheme_, std::string("http")) ? HTTP : HTTPS, DEFAULT, fz::to_wstring_from_utf8(uri.host_), uri.port_);
 	pending_commands_.emplace_back(new CConnectCommand(server, ServerHandle(), Credentials()));
-	pending_commands_.emplace_back(new CHttpRequestCommand(uri, writer_factory_holder(std::make_unique<memory_writer_factory>(L"Updater", output_buffer_, 1024*1024)), "GET", reader_factory_holder(), true));
+	pending_commands_.emplace_back(new CHttpRequestCommand(uri, fz::writer_factory_holder(std::make_unique<fz::buffer_writer_factory>(output_buffer_, L"Updater", 1024*1024)), "GET", fz::reader_factory_holder(), true));
 
 	return ContinueDownload();
 }
@@ -338,9 +348,9 @@ bool CUpdater::CreateTransferCommand(std::wstring const& url, std::wstring const
 	path = path.GetParent();
 
 	transfer_flags const flags = transfer_flags::download;
-	auto cmd = new CFileTransferCommand(file_writer_factory(local_file, true), path, file, flags);
+	auto cmd = new CFileTransferCommand(fz::file_writer_factory(local_file, engine_context_.GetThreadPool(), fz::file_writer_flags::fsync), path, file, flags);
 	resume_offset_ = cmd->GetWriter().size();
-	if (resume_offset_ == aio_base::nosize) {
+	if (resume_offset_ == fz::aio_base::nosize) {
 		resume_offset_ = 0;
 	}
 	pending_commands_.emplace_back(cmd);
@@ -549,6 +559,9 @@ std::wstring CUpdater::GetLocalFile(build const& b, bool allow_existing)
 {
 	std::wstring const fn = GetFilename(b.url_);
 	std::wstring const dl = GetDownloadDir().GetPath();
+	if (dl.empty()) {
+		return {};
+	}
 
 	int i = 1;
 	std::wstring f = dl + fn;
