@@ -442,7 +442,7 @@ void CFtpControlSocket::TransferEnd()
 
 	if (reason == TransferEndReason::failed_tls_resumption) {
 		log(logmsg::error, _("TLS session resumption on data connection failed. Closing control connection to start over."));
-		ResetOperation(FZ_REPLY_ERROR | FZ_REPLY_DISCONNECTED);
+		DoClose(FZ_REPLY_ERROR | FZ_REPLY_DISCONNECTED);
 		return;
 	}
 
@@ -581,7 +581,7 @@ void CFtpControlSocket::RemoveDir(CServerPath const& path, std::wstring const& s
 	Push(std::move(pData));
 }
 
-void CFtpControlSocket::Mkdir(CServerPath const& path)
+void CFtpControlSocket::Mkdir(CServerPath const& path, transfer_flags const&)
 {
 	auto pData = std::make_unique<CFtpMkdirOpData>(*this);
 	pData->path_ = path;
