@@ -20,12 +20,17 @@
 #include <assert.h>
 #include <string.h>
 
+int CHttpConnectOpData::Send()
+{
+	return controlSocket_.buffer_pool_ ? FZ_REPLY_OK : (FZ_REPLY_ERROR | FZ_REPLY_DISCONNECTED);
+}
+
 uint64_t HttpRequest::update_content_length()
 {
 	uint64_t ret{};
 	if (body_) {
 		ret = body_->size();
-		if (ret != aio_base::nosize) {
+		if (ret != fz::aio_base::nosize) {
 			headers_["Content-Length"] = fz::to_string(ret);
 		}
 		else {
@@ -48,11 +53,10 @@ int HttpRequest::reset()
 	flags_ &= (flag_update_transferstatus | flag_confidential_querystring);
 
 	if (body_) {
-		aio_result res = body_->rewind();
-		if (res != aio_result::ok) {
+		if (!body_->rewind()) {
 			return FZ_REPLY_ERROR;
 		}
-		body_buffer_ = fz::nonowning_buffer();
+		body_buffer_.release();
 	}
 
 	return FZ_REPLY_CONTINUE;
@@ -375,3 +379,18 @@ void CHttpControlSocket::SetSocketBufferSizes()
 #endif
 	socket_->set_buffer_sizes(size_read, size_write);
 }
+
+std::string get_host_header(fz::uri const& uri)
+{
+	if (uri.port_ == 0) {
+		return uri.host_;
+	}
+	else if (uri.port_ == 443 && fz::equal_insensitive_ascii(uri.scheme_, "https")) {
+		return uri.host_;
+	}
+	else if (uri.port_ == 80 && fz::equal_insensitive_ascii(uri.scheme_, "http")) {
+		return uri.host_;
+	}
+
+	return uri.host_ + ":" + fz::to_string(uri.port_);
+}
