@@ -277,6 +277,9 @@ int CHttpRequestOpData::Send()
 				else if (written) {
 					controlSocket_.SetAlive();
 					req.body_buffer_->consume(static_cast<size_t>(written));
+					if (req.body_buffer_->empty()) {
+						req.body_buffer_.release();
+					}
 					dataToSend_ -= written;
 					if (req.flags_ & HttpRequest::flag_update_transferstatus) {
 						engine_.transfer_status_.Update(written);
@@ -873,14 +876,14 @@ int CHttpRequestOpData::ProcessData(unsigned char* data, size_t & remaining)
 					}
 				}
 				else {
-					if (response.body_.size() < 1024*1024*16) {
+					if (response.body_.size() < response.max_body_size_) {
 						response.body_.append(data, remaining);
 					}
 					remaining = 0;
 				}
 			}
 			else {
-				if (response.body_.size() < 1024*1024*16) {
+				if (response.body_.size() < response.max_body_size_) {
 					response.body_.append(data, remaining);
 				}
 				remaining = 0;
