@@ -1,6 +1,7 @@
 #include "filezilla.h"
 
 #include <libfilezilla/format.hpp>
+#include <libfilezilla/local_filesys.hpp>
 #include <libfilezilla/time.hpp>
 #include <libfilezilla/tls_layer.hpp>
 
@@ -69,7 +70,7 @@ std::string GetSystemErrorDescription(int err)
 
 namespace fz {
 
-std::wstring str_tolower(std::wstring const& source)
+std::wstring str_tolower(std::wstring_view const& source)
 {
 	std::wstring ret;
 	ret.reserve(source.size());
@@ -79,4 +80,45 @@ std::wstring str_tolower(std::wstring const& source)
 	return ret;
 }
 
+void str_tolower_inplace(std::wstring & source)
+{
+	for (auto & c : source) {
+		c = std::towlower(c);
+	}
+}
+
+std::wstring str_toupper(std::wstring_view const& source)
+{
+	std::wstring ret;
+	ret.reserve(source.size());
+	for (auto const& c : source) {
+		ret.push_back(std::towupper(c));
+	}
+	return ret;
+}
+
+void str_toupper_inplace(std::wstring & source)
+{
+	for (auto & c : source) {
+		c = std::towupper(c);
+	}
+}
+
+}
+
+std::wstring GetEnv(char const *name)
+{
+	std::wstring ret;
+	if (name) {
+		auto *v = getenv(name);
+		if (v) {
+			ret = fz::to_wstring(v);
+		}
+	}
+	return ret;
+}
+
+bool FileExists(std::wstring const &file)
+{
+	return fz::local_filesys::get_file_type(fz::to_native(file), true) == fz::local_filesys::file;
 }
