@@ -30,16 +30,6 @@ public:
 	bool IsBusy() const;
 	bool IsConnected() const;
 
-	// IsActive returns true only if data has been transferred in the
-	// given direction since the last time IsActive was called with
-	// the same argument.
-	enum _direction
-	{
-		send,
-		recv
-	};
-	static bool IsActive(_direction direction);
-
 	// Returns the next pending notification.
 	// It is mandatory to call this function until it returns a nullptr each time you
 	// get the pending notifications event, or you'll either lose notifications
