@@ -1,10 +1,12 @@
 #ifndef FILEZILLA_ENGINE_SIZEFORMATTING_BASE_HEADER
 #define FILEZILLA_ENGINE_SIZEFORMATTING_BASE_HEADER
 
+#include "visibility.h"
+
 #include <string>
 
 class COptionsBase;
-class CSizeFormatBase
+class FZC_PUBLIC_SYMBOL CSizeFormatBase
 {
 public:
 	enum _format
