@@ -12,6 +12,7 @@
 #include "msgbox.h"
 #include "themeprovider.h"
 #include "wxfilesystem_blob_handler.h"
+#include "renderer.h"
 #include "../commonui/fz_paths.h"
 #include "../include/version.h"
 #include <libfilezilla/local_filesys.hpp>
@@ -167,6 +168,8 @@ bool CFileZillaApp::OnInit()
 	wxSystemOptions::SetOption(_T("mac.textcontrol-use-spell-checker"), 0);
 #endif
 
+	InitRenderer();
+
 	int cmdline_result = ProcessCommandLine();
 	if (!cmdline_result) {
 		return false;
@@ -181,6 +184,8 @@ bool CFileZillaApp::OnInit()
 		return false;
 	}
 
+	options_ = std::make_unique<COptions>();
+
 #if USE_MAC_SANDBOX
 	// Set PUTTYDIR so that fzsftp uses the sandboxed home to put settings.
 	std::wstring home = GetEnv("HOME");
@@ -192,8 +197,6 @@ bool CFileZillaApp::OnInit()
 	}
 #endif
 
-	options_ = std::make_unique<COptions>();
-
 	InitLocale();
 
 #ifndef _DEBUG
