@@ -39,7 +39,7 @@ public:
 	typedef std::function<void(ChmodUICommand &, CState &)> ChmodHandler;
 
 	static std::map<ServerProtocol, CRemoteListView::ChmodHandler> chmodHandlers;
-	
+
 protected:
 	virtual wxString GetItemText(int item, unsigned int column);
 
@@ -83,7 +83,7 @@ protected:
 	std::shared_ptr<CDirectoryListing> m_pDirectoryListing;
 
 	// Caller is responsible to check selection is valid!
-	void TransferSelectedFiles(const CLocalPath& local_parent, bool queue_only);
+	void TransferSelectedFiles(const CLocalPath& local_parent, bool queue_only, transfer_flags custom_flags = transfer_flags::none, transfer_flags custom_flags_mask = transfer_flags::none);
 
 	void HandleGenericChmod(ChmodUICommand &command);
 
