@@ -1,19 +1,9 @@
 #ifndef FILEZILLA_FILE_UTILS_HEADER
 #define FILEZILLA_FILE_UTILS_HEADER
 
+#include "../commonui/file_utils.h"
 #include <libfilezilla/recursive_remove.hpp>
 
-#include <optional>
-
-// Quotation rules:
-// - Args containing spaces double-quotes need to be quotes by enclosing in double-quotes.
-// - If an arg is quoted, contained double-quotes are doubled
-//
-// - Example: "foo""bar" is the quoted representation of foo"bar
-std::wstring QuoteCommand(std::vector<std::wstring> const& cmd_with_args);
-std::vector<std::wstring> UnquoteCommand(std::wstring_view command);
-
-std::optional<std::wstring> UnquoteFirst(std::wstring_view & command);
 
 // Returns the association for a file based on its extension
 std::vector<std::wstring> GetSystemAssociation(std::wstring const& file);
@@ -22,18 +12,11 @@ std::vector<fz::native_string> AssociationToCommand(std::vector<std::wstring> co
 
 bool ProgramExists(std::wstring const& editor);
 
-// Returns a file:// URL
-std::wstring GetAsURL(std::wstring const& dir);
-
 // Opens specified directory in local file manager, e.g. Explorer on Windows
 bool OpenInFileManager(std::wstring const& dir);
 
 bool RenameFile(wxWindow* pWnd, wxString dir, wxString from, wxString to);
 
-CLocalPath GetDownloadDir();
-
-std::wstring GetExtension(std::wstring_view file);
-
 class gui_recursive_remove final : public fz::recursive_remove
 {
 public:
@@ -67,6 +50,4 @@ private:
 	wxWindow* parent_;
 };
 
-bool IsInvalidChar(wchar_t c, bool includeQuotesAndBreaks = false);
-
 #endif
