@@ -593,6 +593,7 @@ private:
 	int m_focusItem{-1};
 	std::vector<bool> m_selections;
 	int m_pending_focus_processing{};
+	bool updateAllSelections_{};
 #endif
 
 #if defined(__WXGTK__) && !defined(__WXGTK3__)
@@ -613,6 +614,7 @@ private:
 	void OnProcessMouseEvent(wxCommandEvent& event);
 #endif
 	void OnKeyDown(wxKeyEvent& event);
+	void OnColorChange(wxSysColourChangedEvent & ev);
 
 	COptionsBase& options_;
 
