@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "filezillaapp.h"
 
 #include "state.h"
@@ -9,6 +9,7 @@
 
 #include <wx/bmpbuttn.h>
 #include <wx/dcclient.h>
+#include <wx/menu.h>
 
 wxWindowID const ID_SEARCH_TEXT = wxWindow::NewControlId();
 wxWindowID const ID_OPTIONS_MENU_BUTTON = wxWindow::NewControlId();
