@@ -10,8 +10,8 @@ EVT_CONTEXT_MENU(CQueueViewSuccessful::OnContextMenu)
 EVT_MENU(XRCID("ID_AUTOCLEAR"), CQueueViewSuccessful::OnMenuAutoClear)
 END_EVENT_TABLE()
 
-CQueueViewSuccessful::CQueueViewSuccessful(CQueue* parent, int index)
-	: CQueueViewFailed(parent, index, _("Successful transfers"))
+CQueueViewSuccessful::CQueueViewSuccessful(CQueue* parent, COptionsBase & options, int index)
+	: CQueueViewFailed(parent, options, index, _("Successful transfers"))
 {
 	std::vector<ColumnId> extraCols({colTime});
 	CreateColumns(extraCols);
