@@ -1126,6 +1126,13 @@ void CSiteManagerDialog::OnSelChanged(wxTreeEvent& evt)
 		m_is_deleting = false;
 	}
 
+#if !defined(__WXMSW__) && wxCHECK_VERSION(3, 2, 1)
+	auto focused = tree_->GetFocusedItem();
+	if (focused) {
+		tree_->EnsureVisible(focused);
+	}
+#endif
+
 	wxWindowUpdateLocker l(this);
 	SetCtrlState();
 }
