@@ -31,7 +31,7 @@ void CSpeedLimitsDialog::Run(wxWindow* parent)
 		enable = false;
 	}
 
-	if (!Create(parent, -1, _("Speed limits"))) {
+	if (!Create(parent, nullID, _("Speed limits"))) {
 		return;
 	}
 
@@ -41,12 +41,12 @@ void CSpeedLimitsDialog::Run(wxWindow* parent)
 	auto split = lay.createFlex(2);
 	main->Add(split);
 
-	split->Add(new wxStaticBitmap(this, -1, CThemeProvider::Get()->CreateBitmap("ART_SPEEDLIMITS", wxString(), CThemeProvider::GetIconSize(iconSizeLarge))));
+	split->Add(CThemeProvider::Get()->createStaticBitmap(this, L"ART_SPEEDLIMITS", iconSizeLarge));
 
 	auto right = lay.createFlex(1);
 	split->Add(right);
 
-	impl_->enable_ = new wxCheckBox(this, -1, _("&Enable speed limits"));
+	impl_->enable_ = new wxCheckBox(this, nullID, _("&Enable speed limits"));
 	impl_->enable_->SetFocus();
 	right->Add(impl_->enable_);
 
@@ -55,16 +55,16 @@ void CSpeedLimitsDialog::Run(wxWindow* parent)
 
 	wxString const unit = CSizeFormat::GetUnitWithBase(CSizeFormat::kilo, 1024);
 
-	inner->Add(new wxStaticText(this, -1, _("Download &limit:")), lay.valign);
-	impl_->download_ = new wxTextCtrlEx(this, -1);
+	inner->Add(new wxStaticText(this, nullID, _("Download &limit:")), lay.valign);
+	impl_->download_ = new wxTextCtrlEx(this, nullID);
 	inner->Add(impl_->download_, lay.valign)->SetMinSize(wxSize(lay.dlgUnits(35), -1));
-	inner->Add(new wxStaticText(this, -1, wxString::Format(_("(in %s/s)"), unit)), lay.valign);
-	inner->Add(new wxStaticText(this, -1, _("U&pload limit:")), lay.valign);
+	inner->Add(new wxStaticText(this, nullID, wxString::Format(_("(in %s/s)"), unit)), lay.valign);
+	inner->Add(new wxStaticText(this, nullID, _("U&pload limit:")), lay.valign);
 	impl_->upload_ = new wxTextCtrlEx(this, -1);
 	inner->Add(impl_->upload_, lay.valign)->SetMinSize(wxSize(lay.dlgUnits(35), -1));
-	inner->Add(new wxStaticText(this, -1, wxString::Format(_("(in %s/s)"), unit)), lay.valign);
+	inner->Add(new wxStaticText(this, nullID, wxString::Format(_("(in %s/s)"), unit)), lay.valign);
 	
-	right->Add(new wxStaticText(this, -1, _("Enter 0 for unlimited speed.")));
+	right->Add(new wxStaticText(this, nullID, _("Enter 0 for unlimited speed.")));
 
 	auto buttons = lay.createButtonSizer(this, main, true);
 
