@@ -11,10 +11,13 @@ public:
 	void SetHeader(CViewHeader* pWnd);
 	CViewHeader* GetHeader() { return m_pHeader; }
 	CViewHeader* DetachHeader();
-	void SetStatusBar(wxStatusBar* pStatusBar);
-	wxStatusBar* GetStatusBar() { return m_pStatusBar; }
+	void SetStatusBar(wxWindow* pStatusBar);
+	wxWindow* GetStatusBar() { return m_pStatusBar; }
 
 	void SetFooter(wxWindow* footer);
+	void SetSearchPanel(wxWindow* panel);
+
+	void ShowSearchPanel();
 
 protected:
 	void Arrange(wxWindow* child, wxRect& clientRect, bool top);
@@ -23,9 +26,10 @@ protected:
 
 	wxWindow* m_pWnd{};
 	CViewHeader* m_pHeader{};
-	wxStatusBar* m_pStatusBar{};
+	wxWindow* m_pStatusBar{};
 
 	wxWindow* m_pFooter{};
+	wxWindow* m_pSearchPanel{};
 
 	DECLARE_EVENT_TABLE()
 	void OnSize(wxSizeEvent&);
