@@ -18,12 +18,21 @@
 
 #ifdef __WXMSW__
 const int border_offset = 0;
+#elif defined(__WXMAC__) && wxCHECK_VERSION(3, 2, 1)
+const int border_offset = 12;
 #elif defined(__WXMAC__)
 const int border_offset = 6;
 #else
 const int border_offset = 10;
 #endif
 
+#if defined(__WXMAC__) && wxCHECK_VERSION(3, 2, 1)
+const int combo_offset = -1;
+#else
+const int combo_offset = 0;
+#endif
+
+
 // wxComboBox derived class which captures WM_CANCELMODE under Windows
 class CComboBoxEx : public wxComboBox
 {
@@ -101,6 +110,7 @@ void CViewHeader::OnSize(wxSizeEvent&)
 	rect.SetX(m_cbOffset);
 	rect.Deflate(0, border_offset / 2);
 	rect.SetWidth(std::max(0, rect.GetWidth() - border_offset / 2));
+	rect.y += combo_offset;
 	if (m_pComboBox) {
 		m_pComboBox->SetSize(rect);
 	}
@@ -514,7 +524,7 @@ void CLocalViewHeader::OnTextEnter(wxCommandEvent&)
 void CLocalViewHeader::OnStateChange(t_statechange_notifications notification, std::wstring const&, const void*)
 {
 	if (notification == STATECHANGE_SERVER) {
-		m_windowTinter->SetBackgroundTint(site_colour_to_wx(m_state.GetSite().m_colour));
+		m_windowTinter->SetBackgroundTint(m_state.GetSite().m_colour);
 	}
 	else if (notification == STATECHANGE_LOCAL_DIR) {
 #ifdef __WXGTK__
@@ -542,7 +552,7 @@ CRemoteViewHeader::CRemoteViewHeader(wxWindow* pParent, CState& state)
 void CRemoteViewHeader::OnStateChange(t_statechange_notifications notification, std::wstring const&, const void*)
 {
 	if (notification == STATECHANGE_SERVER) {
-		m_windowTinter->SetBackgroundTint(site_colour_to_wx(m_state.GetSite().m_colour));
+		m_windowTinter->SetBackgroundTint(m_state.GetSite().m_colour);
 	}
 	else if (notification == STATECHANGE_REMOTE_DIR) {
 		m_path = m_state.GetRemotePath();
