@@ -4,14 +4,16 @@
 // This class get used to remember toplevel window size and position across
 // sessions.
 
+#include "Options.h"
+
 class CWindowStateManager final : public wxEvtHandler
 {
 public:
-	CWindowStateManager(wxTopLevelWindow* pWindow);
+	explicit CWindowStateManager(wxTopLevelWindow* pWindow);
 	virtual ~CWindowStateManager();
 
-	bool Restore(const unsigned int optionId, const wxSize& default_size = wxSize(-1, -1));
-	void Remember(unsigned int optionId);
+	bool Restore(interfaceOptions const optionId, const wxSize& default_size = wxSize(-1, -1));
+	void Remember(interfaceOptions const optionId);
 
 	static wxRect GetScreenDimensions();
 
@@ -23,7 +25,7 @@ public:
 #endif
 
 protected:
-	bool ReadDefaults(const unsigned int optionId, bool& maximized, wxPoint& position, wxSize& size);
+	bool ReadDefaults(interfaceOptions const optionId, bool& maximized, wxPoint& position, wxSize& size);
 
 	wxTopLevelWindow* m_pWindow;
 
